class Environment(object):
    def __init__(self, name: str, api_url: str, web_url: str, read_only: bool = True):
        self._name = name
        self._api_url = api_url
        self._web_url = web_url
        self._read_only = read_only

    @property
    def name(self) -> str:
        return self._name

    @property
    def api_url(self) -> str:
        return self._api_url

    @property
    def web_url(self) -> str:
        return self._web_url

    @property
    def read_only(self) -> bool:
        return self._read_only

    def __str__(self):
        return self._name

    def __repr__(self):
        return f"{self._name} ({self._api_url})"



class LudiaLudomError(Exception):
    pass


class APIError(LudiaLudomError):
    pass


class SignatureError(LudiaLudomError):
    pass


class InvalidSignatureGenerated(LudiaLudomError):
    def __init__(self, secret: str, message: str, signature: str):
        self._secret = secret
        self._message = message
        self._signature = signature

    @property
    def secret(self) -> str:
        return self._secret

    @property
    def message(self) -> str:
        return self._message

    @property
    def signature(self) -> str:
        return self._signature



import os
from setuptools import setup

BASE_DIR = os.path.abspath(os.path.dirname(__file__))

REQUIRED = [
    'requests>=2.21.0'
]


def read_files(files):
    data = []
    for file in files:
        with open(file) as f:
            data.append(f.read())
    return "\n".join(data)


meta = {}
with open('./ludialudom/version.py') as f:
    exec(f.read(), meta)

setup(
    name='ludialudom',
    version=meta['__version__'],
    packages=['ludialudom', 'ludialudom.resources'],
    install_requires=REQUIRED,
    url='https://gitlab.backbone.sk/darujme/ludialudom-python',
    license='proprietary',
    author='Jakub Dubec',
    author_email='jakub.dubec@backbone.sk',
    description='Python API client for LudiaLudom',
    long_description=read_files(['README.md', 'CHANGELOG.md']),
    long_description_content_type='text/markdown',
    keywords=['ludialudom', 'requests', 'client', 'api'],
    classifiers=[
        # As from https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'License :: Other/Proprietary License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
